@@ -185,7 +185,8 @@ get.label <- function(dat, label.name) {
 
 #' Assign Stata Labels to a Variable
 #'
-#' Assign value labels from a Stata label set to a variable.
+#' Assign value labels from a Stata label set to a variable. If duplicated labels are found, 
+#' unique labels will be generated according the following scheme: "label_(integer code)".
 #'
 #' @param dat \emph{data.frame.} Data.frame created by \code{read.dta13}.
 #' @param var.name \emph{character.} Name of the variable in the data.frame
@@ -210,6 +211,17 @@ set.label <- function(dat, var.name, lang=NA) {
 
   labtable <- get.label(dat, get.label.name(dat, var.name, lang))
 
+  #check for duplicated labels
+  labcount <- table(names(labtable))
+  if(any(labcount > 1)) {
+    
+    
+    warning(paste0("\n  ",var.name, ":\n  Duplicated factor levels detected - generating unique labels.\n"))
+    labdups <- names(labtable) %in% names(labcount[labcount > 1])
+    # generate unique labels from assigned label and code number
+    names(labtable)[labdups] <- paste0(names(labtable)[labdups], "_(", labtable[labdups], ")")
+  }
+  
   return(factor(tmp, levels=labtable,
                 labels=names(labtable))
   )
@@ -228,7 +240,7 @@ set.label <- function(dat, var.name, lang=NA) {
 #' @return Returns an named vector of variable labels
 #' @author Jan Marvin Garbuszus \email{jan.garbuszus@@ruhr-uni-bochum.de}
 #' @author Sebastian Jeworutzki \email{sebastian.jeworutzki@@ruhr-uni-bochum.de}
-#' @aliases varlabel 
+#' @aliases varlabel
 #' @aliases 'varlabel<-'
 NULL
 
@@ -390,3 +402,28 @@ set.lang <- function(dat, lang=NA, generate.factors=FALSE) {
 saveToExport <- function(x) {
   isTRUE(all.equal(x, as.integer(x)))
 }
+
+
+#' Check max char length of data.frame vectors
+#'
+#' Stata requires us to provide the maximum size of a charactervector as every
+#' row is stored in a bit region of this size.
+#'
+#' Ex: If the max chars size is four, _ is no character in this vector:
+#' 1. row: four
+#' 3. row: one_
+#' 4. row: ____
+#'
+#' If a character vector contains only missings or is empty, we will assign it a
+#' value of one, since Stata otherwise cannot handle what we write.
+#'
+#' @param x vector of data frame
+maxchar <- function(x) {
+  z <- max(nchar(x, type="byte"), na.rm = TRUE)
+
+  # Stata does not allow storing a string of size 0
+  if(is.infinite(z) | (z == 0))
+    z <- 1
+
+  z
+}
