@@ -26,7 +26,8 @@ using namespace Rcpp;
 // @import Rcpp
 // @export
 // [[Rcpp::export]]
-List stata_read(const char * filePath, const bool missing)
+List stata_read(const char * filePath, const bool missing,
+                const IntegerVector selectrows)
 {
   FILE *file = NULL;    // File pointer
 
@@ -52,9 +53,9 @@ List stata_read(const char * filePath, const bool missing)
   List df(0);
 
   if (fbit.compare(expfbit) == 0)
-    df = read_dta(file, missing);
+    df = read_dta(file, missing, selectrows);
   else
-    df = read_pre13_dta(file, missing);
+    df = read_pre13_dta(file, missing, selectrows);
 
   fclose(file);
 
